pub enum BlockHeader {
BlockHeaderV1(BlockHeaderV1),
BlockHeaderV2(BlockHeaderV2),
BlockHeaderV3(BlockHeaderV3),
BlockHeaderV4(BlockHeaderV4),
BlockHeaderV5(BlockHeaderV5),
BlockHeaderV6(BlockHeaderV6),
BlockHeaderV7(BlockHeaderV7),
}Expand description
Versioned BlockHeader data structure. For each next version, document what are the changes between versions.
Variants
BlockHeaderV1(BlockHeaderV1)
BlockHeaderV2(BlockHeaderV2)
BlockHeaderV3(BlockHeaderV3)
BlockHeaderV4(BlockHeaderV4)
BlockHeaderV5(BlockHeaderV5)
BlockHeaderV6(BlockHeaderV6)
BlockHeaderV7(BlockHeaderV7)
Implementations
Sourceimpl BlockHeader
impl BlockHeader
pub fn compute_inner_hash(inner_lite: &[u8], inner_rest: &[u8]) -> CryptoHash
pub fn compute_hash( prev_hash: CryptoHash, inner_lite: &[u8], inner_rest: &[u8], ) -> CryptoHash
Sourcepub fn new(
current_protocol_version: ProtocolVersion,
latest_protocol_version: ProtocolVersion,
height: BlockHeight,
prev_hash: CryptoHash,
block_body_hash: CryptoHash,
prev_state_root: MerkleHash,
prev_chunk_outgoing_receipts_root: MerkleHash,
chunk_headers_root: MerkleHash,
chunk_tx_root: MerkleHash,
outcome_root: MerkleHash,
timestamp: u64,
random_value: CryptoHash,
prev_validator_proposals: Vec<ValidatorStake>,
chunk_mask: Vec<bool>,
block_ordinal: NumBlocks,
epoch_id: EpochId,
next_epoch_id: EpochId,
next_gas_price: Balance,
total_supply: Balance,
signer: &ValidatorSigner,
last_final_block: CryptoHash,
last_ds_final_block: CryptoHash,
epoch_sync_data_hash: Option<CryptoHash>,
approvals: Vec<Option<Box<Signature>>>,
next_bp_hash: CryptoHash,
block_merkle_root: CryptoHash,
prev_height: BlockHeight,
chunk_endorsements: Option<ChunkEndorsementsBitmap>,
shard_split: Option<(ShardId, AccountId)>,
prev_last_certified_block_epoch_id: Option<EpochId>,
spice_chunk_endorsement_stats: Option<Vec<SpiceChunkEndorsementStats>>,
) -> Self
pub fn new( current_protocol_version: ProtocolVersion, latest_protocol_version: ProtocolVersion, height: BlockHeight, prev_hash: CryptoHash, block_body_hash: CryptoHash, prev_state_root: MerkleHash, prev_chunk_outgoing_receipts_root: MerkleHash, chunk_headers_root: MerkleHash, chunk_tx_root: MerkleHash, outcome_root: MerkleHash, timestamp: u64, random_value: CryptoHash, prev_validator_proposals: Vec<ValidatorStake>, chunk_mask: Vec<bool>, block_ordinal: NumBlocks, epoch_id: EpochId, next_epoch_id: EpochId, next_gas_price: Balance, total_supply: Balance, signer: &ValidatorSigner, last_final_block: CryptoHash, last_ds_final_block: CryptoHash, epoch_sync_data_hash: Option<CryptoHash>, approvals: Vec<Option<Box<Signature>>>, next_bp_hash: CryptoHash, block_merkle_root: CryptoHash, prev_height: BlockHeight, chunk_endorsements: Option<ChunkEndorsementsBitmap>, shard_split: Option<(ShardId, AccountId)>, prev_last_certified_block_epoch_id: Option<EpochId>, spice_chunk_endorsement_stats: Option<Vec<SpiceChunkEndorsementStats>>, ) -> Self
Creates BlockHeader for a newly produced block.
Sourcepub fn from_view(
expected_hash: &CryptoHash,
epoch_protocol_version: ProtocolVersion,
height: BlockHeight,
prev_hash: CryptoHash,
block_body_hash: CryptoHash,
prev_state_root: MerkleHash,
prev_chunk_outgoing_receipts_root: MerkleHash,
chunk_headers_root: MerkleHash,
chunk_tx_root: MerkleHash,
outcome_root: MerkleHash,
timestamp: u64,
random_value: CryptoHash,
prev_validator_proposals: Vec<ValidatorStake>,
chunk_mask: Vec<bool>,
block_ordinal: NumBlocks,
epoch_id: EpochId,
next_epoch_id: EpochId,
next_gas_price: Balance,
total_supply: Balance,
signature: Signature,
last_final_block: CryptoHash,
last_ds_final_block: CryptoHash,
epoch_sync_data_hash: Option<CryptoHash>,
approvals: Vec<Option<Box<Signature>>>,
next_bp_hash: CryptoHash,
block_merkle_root: CryptoHash,
prev_height: BlockHeight,
chunk_endorsements: Option<ChunkEndorsementsBitmap>,
shard_split: Option<(ShardId, AccountId)>,
prev_last_certified_block_epoch_id: Option<EpochId>,
spice_chunk_endorsement_stats: Option<Vec<SpiceChunkEndorsementStats>>,
) -> Self
pub fn from_view( expected_hash: &CryptoHash, epoch_protocol_version: ProtocolVersion, height: BlockHeight, prev_hash: CryptoHash, block_body_hash: CryptoHash, prev_state_root: MerkleHash, prev_chunk_outgoing_receipts_root: MerkleHash, chunk_headers_root: MerkleHash, chunk_tx_root: MerkleHash, outcome_root: MerkleHash, timestamp: u64, random_value: CryptoHash, prev_validator_proposals: Vec<ValidatorStake>, chunk_mask: Vec<bool>, block_ordinal: NumBlocks, epoch_id: EpochId, next_epoch_id: EpochId, next_gas_price: Balance, total_supply: Balance, signature: Signature, last_final_block: CryptoHash, last_ds_final_block: CryptoHash, epoch_sync_data_hash: Option<CryptoHash>, approvals: Vec<Option<Box<Signature>>>, next_bp_hash: CryptoHash, block_merkle_root: CryptoHash, prev_height: BlockHeight, chunk_endorsements: Option<ChunkEndorsementsBitmap>, shard_split: Option<(ShardId, AccountId)>, prev_last_certified_block_epoch_id: Option<EpochId>, spice_chunk_endorsement_stats: Option<Vec<SpiceChunkEndorsementStats>>, ) -> Self
Creates a new BlockHeader from information in the view of an existing block.
pub fn genesis( genesis_protocol_version: ProtocolVersion, height: BlockHeight, state_root: MerkleHash, block_body_hash: CryptoHash, prev_chunk_outgoing_receipts_root: MerkleHash, chunk_headers_root: MerkleHash, chunk_tx_root: MerkleHash, num_shards: u64, timestamp: Utc, initial_gas_price: Balance, initial_total_supply: Balance, next_bp_hash: CryptoHash, ) -> Self
pub fn is_genesis(&self) -> bool
pub fn hash(&self) -> &CryptoHash
pub fn prev_hash(&self) -> &CryptoHash
pub fn signature(&self) -> &Signature
pub fn height(&self) -> BlockHeight
pub fn prev_height(&self) -> Option<BlockHeight>
pub fn epoch_id(&self) -> &EpochId
pub fn next_epoch_id(&self) -> &EpochId
pub fn prev_state_root(&self) -> &MerkleHash
pub fn prev_chunk_outgoing_receipts_root(&self) -> &MerkleHash
pub fn chunk_headers_root(&self) -> &MerkleHash
pub fn chunk_tx_root(&self) -> &MerkleHash
pub fn chunks_included(&self) -> u64
pub fn outcome_root(&self) -> &MerkleHash
pub fn block_body_hash(&self) -> Option<CryptoHash>
pub fn raw_timestamp(&self) -> u64
pub fn prev_validator_proposals(&self) -> ValidatorStakeIter<'_> ⓘ
pub fn chunk_mask(&self) -> &[bool]
pub fn block_ordinal(&self) -> NumBlocks
pub fn next_gas_price(&self) -> Balance
pub fn total_supply(&self) -> Balance
pub fn random_value(&self) -> &CryptoHash
pub fn last_final_block(&self) -> &CryptoHash
Sourcepub fn last_final_block_for_height(
&self,
target_height: BlockHeight,
) -> &CryptoHash
pub fn last_final_block_for_height( &self, target_height: BlockHeight, ) -> &CryptoHash
Get the hash of what will be considered the last final block after a new block with
target_height is produced on top of this (self) block.
pub fn last_ds_final_block(&self) -> &CryptoHash
pub fn next_bp_hash(&self) -> &CryptoHash
pub fn block_merkle_root(&self) -> &CryptoHash
pub fn epoch_sync_data_hash(&self) -> Option<CryptoHash>
pub fn approvals(&self) -> &[Option<Box<Signature>>]
Sourcepub fn verify_block_producer(&self, public_key: &PublicKey) -> bool
pub fn verify_block_producer(&self, public_key: &PublicKey) -> bool
Verifies that given public key produced the block.
pub fn timestamp(&self) -> Utc
pub fn num_approvals(&self) -> u64
pub fn verify_chunks_included(&self) -> bool
pub fn latest_protocol_version(&self) -> u32
pub fn inner_lite_bytes(&self) -> Vec<u8> ⓘ
pub fn inner_rest_bytes(&self) -> Vec<u8> ⓘ
pub fn chunk_endorsements(&self) -> Option<&ChunkEndorsementsBitmap>
pub fn inner_lite(&self) -> &BlockHeaderInnerLite
Sourcepub fn challenges_present(&self) -> bool
pub fn challenges_present(&self) -> bool
As challenges are now deprecated and not supported, a valid block should not have challenges.
Sourcepub fn shard_split(&self) -> Option<&(ShardId, AccountId)>
pub fn shard_split(&self) -> Option<&(ShardId, AccountId)>
Shard ID and boundary account for the upcoming resharding. This field may be set only for the last block of an epoch. Split proposed at the end of epoch N will be effective since the beginning of epoch N+2.
Sourcepub fn prev_last_certified_block_epoch_id(&self) -> Option<&EpochId>
pub fn prev_last_certified_block_epoch_id(&self) -> Option<&EpochId>
Epoch ID of the last block whose spice execution results are certified.
Returns None for header versions prior to V7.
Sourcepub fn spice_chunk_endorsement_stats(
&self,
) -> Option<&[SpiceChunkEndorsementStats]>
pub fn spice_chunk_endorsement_stats( &self, ) -> Option<&[SpiceChunkEndorsementStats]>
Set only on the last block of an epoch; None before header V7.
See SpiceChunkEndorsementStats.
Sourceimpl BlockHeader
impl BlockHeader
pub fn prod_genesis( height: BlockHeight, state_root: MerkleHash, prev_chunk_outgoing_receipts_root: MerkleHash, chunk_headers_root: MerkleHash, chunk_tx_root: MerkleHash, timestamp: Utc, initial_gas_price: Balance, initial_total_supply: Balance, next_bp_hash: CryptoHash, ) -> Self