pub struct BlockHeaderInnerRestV3 {Show 17 fields
pub prev_chunk_outgoing_receipts_root: MerkleHash,
pub chunk_headers_root: MerkleHash,
pub chunk_tx_root: MerkleHash,
pub challenges_root: MerkleHash,
pub random_value: CryptoHash,
pub prev_validator_proposals: Vec<ValidatorStake>,
pub chunk_mask: Vec<bool>,
pub next_gas_price: Balance,
pub total_supply: Balance,
pub challenges_result: Vec<SlashedValidator>,
pub last_final_block: CryptoHash,
pub last_ds_final_block: CryptoHash,
pub block_ordinal: NumBlocks,
pub prev_height: BlockHeight,
pub epoch_sync_data_hash: Option<CryptoHash>,
pub approvals: Vec<Option<Box<Signature>>>,
pub latest_protocol_version: ProtocolVersion,
}Expand description
Add prev_height
Add block_ordinal
Add epoch_sync_data_hash
Use new ValidatorStake struct
Fields
prev_chunk_outgoing_receipts_root: MerkleHashRoot hash of the previous chunks’ outgoing receipts in the given block.
chunk_headers_root: MerkleHashRoot hash of the chunk headers in the given block.
chunk_tx_root: MerkleHashRoot hash of the chunk transactions in the given block.
challenges_root: MerkleHashRoot hash of the challenges in the given block.
random_value: CryptoHashThe output of the randomness beacon
prev_validator_proposals: Vec<ValidatorStake>Validator proposals from the previous chunks.
chunk_mask: Vec<bool>Mask for new chunks included in the block
next_gas_price: BalanceGas price for chunks in the next block.
total_supply: BalanceTotal supply of tokens in the system
challenges_result: Vec<SlashedValidator>List of challenges result from previous block.
last_final_block: CryptoHashLast block that has full BFT finality
last_ds_final_block: CryptoHashLast block that has doomslug finality
block_ordinal: NumBlocksThe ordinal of the Block on the Canonical Chain
prev_height: BlockHeightepoch_sync_data_hash: Option<CryptoHash>approvals: Vec<Option<Box<Signature>>>All the approvals included in this block
latest_protocol_version: ProtocolVersionLatest protocol version that this block producer has.