pub struct BlockHeaderInnerRestV6 {Show 18 fields
pub block_body_hash: CryptoHash,
pub prev_chunk_outgoing_receipts_root: MerkleHash,
pub chunk_headers_root: MerkleHash,
pub chunk_tx_root: MerkleHash,
pub random_value: CryptoHash,
pub prev_validator_proposals: Vec<ValidatorStake>,
pub chunk_mask: Vec<bool>,
pub next_gas_price: Balance,
pub total_supply: Balance,
pub last_final_block: CryptoHash,
pub last_ds_final_block: CryptoHash,
pub block_ordinal: NumBlocks,
pub prev_height: BlockHeight,
pub epoch_sync_data_hash: Option<CryptoHash>,
pub approvals: Vec<Option<Box<Signature>>>,
pub latest_protocol_version: ProtocolVersion,
pub chunk_endorsements: ChunkEndorsementsBitmap,
pub shard_split: Option<(ShardId, AccountId)>,
}Expand description
Add shard_split, remove challenges
Fields
block_body_hash: CryptoHashHash of block body
prev_chunk_outgoing_receipts_root: MerkleHashRoot hash of the previous chunks’ outgoing receipts in the given block.
chunk_headers_root: MerkleHashRoot hash of the chunk headers in the given block.
chunk_tx_root: MerkleHashRoot hash of the chunk transactions in the given block.
random_value: CryptoHashThe output of the randomness beacon
prev_validator_proposals: Vec<ValidatorStake>Validator proposals from the previous chunks.
chunk_mask: Vec<bool>Mask for new chunks included in the block
next_gas_price: BalanceGas price for chunks in the next block.
total_supply: BalanceTotal supply of tokens in the system
last_final_block: CryptoHashLast block that has full BFT finality
last_ds_final_block: CryptoHashLast block that has doomslug finality
block_ordinal: NumBlocksThe ordinal of the Block on the Canonical Chain
prev_height: BlockHeightepoch_sync_data_hash: Option<CryptoHash>approvals: Vec<Option<Box<Signature>>>All the approvals included in this block
latest_protocol_version: ProtocolVersionLatest protocol version that this block producer has.
chunk_endorsements: ChunkEndorsementsBitmapshard_split: Option<(ShardId, AccountId)>Shard ID and boundary account for the upcoming resharding. This field may be set only for the last block of an epoch. Split proposed at the end of epoch N will be executed in epoch N+2.