pub struct BlockHeaderV3 {
pub prev_hash: CryptoHash,
pub inner_lite: BlockHeaderInnerLite,
pub inner_rest: BlockHeaderInnerRestV3,
pub signature: Signature,
pub hash: CryptoHash,
}Expand description
V2 -> V3: Add prev_height to inner_rest and use new ValidatorStake
Fields
prev_hash: CryptoHashinner_lite: BlockHeaderInnerLiteInner part of the block header that gets hashed, split into two parts, one that is sent to light clients, and the rest
inner_rest: BlockHeaderInnerRestV3signature: SignatureSignature of the block producer.
hash: CryptoHashCached value of hash for this block.
Implementations
Sourceimpl BlockHeaderV3
impl BlockHeaderV3