Enum near_primitives::errors::ActionErrorKind
source · [−]pub enum ActionErrorKind {
Show 16 variants
AccountAlreadyExists {
account_id: AccountId,
},
AccountDoesNotExist {
account_id: AccountId,
},
CreateAccountOnlyByRegistrar {
account_id: AccountId,
registrar_account_id: AccountId,
predecessor_id: AccountId,
},
CreateAccountNotAllowed {
account_id: AccountId,
predecessor_id: AccountId,
},
ActorNoPermission {
account_id: AccountId,
actor_id: AccountId,
},
DeleteKeyDoesNotExist {
account_id: AccountId,
public_key: PublicKey,
},
AddKeyAlreadyExists {
account_id: AccountId,
public_key: PublicKey,
},
DeleteAccountStaking {
account_id: AccountId,
},
LackBalanceForState {
account_id: AccountId,
amount: Balance,
},
TriesToUnstake {
account_id: AccountId,
},
TriesToStake {
account_id: AccountId,
stake: Balance,
locked: Balance,
balance: Balance,
},
InsufficientStake {
account_id: AccountId,
stake: Balance,
minimum_stake: Balance,
},
FunctionCallError(FunctionCallErrorSer),
NewReceiptValidationError(ReceiptValidationError),
OnlyImplicitAccountCreationAllowed {
account_id: AccountId,
},
DeleteAccountWithLargeState {
account_id: AccountId,
},
}Variants
AccountAlreadyExists
Fields
account_id: AccountIdHappens when CreateAccount action tries to create an account with account_id which is already exists in the storage
AccountDoesNotExist
Fields
account_id: AccountIdHappens when TX receiver_id doesn’t exist (but action is not Action::CreateAccount)
CreateAccountOnlyByRegistrar
A top-level account ID can only be created by registrar.
CreateAccountNotAllowed
A newly created account must be under a namespace of the creator account
ActorNoPermission
Administrative actions like DeployContract, Stake, AddKey, DeleteKey. can be proceed only if sender=receiver
or the first TX action is a CreateAccount action
DeleteKeyDoesNotExist
Account tries to remove an access key that doesn’t exist
AddKeyAlreadyExists
The public key is already used for an existing access key
DeleteAccountStaking
Fields
account_id: AccountIdAccount is staking and can not be deleted
LackBalanceForState
Fields
account_id: AccountIdAn account which needs balance
amount: BalanceBalance required to complete an action.
ActionReceipt can’t be completed, because the remaining balance will not be enough to cover storage.
TriesToUnstake
Fields
account_id: AccountIdAccount is not yet staked, but tries to unstake
TriesToStake
The account doesn’t have enough balance to increase the stake.
InsufficientStake
FunctionCallError(FunctionCallErrorSer)
An error occurred during a FunctionCall Action, parameter is debug message.
NewReceiptValidationError(ReceiptValidationError)
Error occurs when a new ActionReceipt created by the FunctionCall action fails
receipt validation.
OnlyImplicitAccountCreationAllowed
Fields
account_id: AccountIdError occurs when a CreateAccount action is called on hex-characters
account of length 64. See implicit account creation NEP:
https://github.com/nearprotocol/NEPs/pull/71.
DeleteAccountWithLargeState
Fields
account_id: AccountIdDelete account whose state is large is temporarily banned.