pub enum ActionsValidationError {
    DeleteActionMustBeFinal,
    TotalPrepaidGasExceeded {
        total_prepaid_gas: Gas,
        limit: Gas,
    },
    TotalNumberOfActionsExceeded {
        total_number_of_actions: u64,
        limit: u64,
    },
    AddKeyMethodNamesNumberOfBytesExceeded {
        total_number_of_bytes: u64,
        limit: u64,
    },
    AddKeyMethodNameLengthExceeded {
        length: u64,
        limit: u64,
    },
    IntegerOverflow,
    InvalidAccountId {
        account_id: String,
    },
    ContractSizeExceeded {
        size: u64,
        limit: u64,
    },
    FunctionCallMethodNameLengthExceeded {
        length: u64,
        limit: u64,
    },
    FunctionCallArgumentsLengthExceeded {
        length: u64,
        limit: u64,
    },
    UnsuitableStakingKey {
        public_key: PublicKey,
    },
    FunctionCallZeroAttachedGas,
}
Describes the error for validating a list of actions.

Variants

DeleteActionMustBeFinal

The delete action must be a final aciton in transaction

TotalPrepaidGasExceeded

Fields

total_prepaid_gas: Gas
limit: Gas

The total prepaid gas (for all given actions) exceeded the limit.

TotalNumberOfActionsExceeded

Fields

total_number_of_actions: u64
limit: u64

The number of actions exceeded the given limit.

AddKeyMethodNamesNumberOfBytesExceeded

Fields

total_number_of_bytes: u64
limit: u64

The total number of bytes of the method names exceeded the limit in a Add Key action.

AddKeyMethodNameLengthExceeded

Fields

length: u64
limit: u64

The length of some method name exceeded the limit in a Add Key action.

IntegerOverflow

Integer overflow during a compute.

InvalidAccountId

Fields

account_id: String

Invalid account ID.

ContractSizeExceeded

Fields

size: u64
limit: u64

The size of the contract code exceeded the limit in a DeployContract action.

FunctionCallMethodNameLengthExceeded

Fields

length: u64
limit: u64

The length of the method name exceeded the limit in a Function Call action.

FunctionCallArgumentsLengthExceeded

Fields

length: u64
limit: u64

The length of the arguments exceeded the limit in a Function Call action.

UnsuitableStakingKey

Fields

public_key: PublicKey

An attempt to stake with a public key that is not convertible to ristretto.

FunctionCallZeroAttachedGas

The attached amount of gas in a FunctionCall action has to be a positive number.