Enum near_primitives::errors::EpochError
source · [−]pub enum EpochError {
ThresholdError {
stake_sum: Balance,
num_seats: u64,
},
EpochOutOfBounds(EpochId),
MissingBlock(CryptoHash),
IOErr(String),
NotAValidator(AccountId, EpochId),
ShardingError(String),
NotEnoughValidators {
num_validators: u64,
num_shards: u64,
},
}Variants
ThresholdError
Error calculating threshold from given stakes for given number of seats. Only should happened if calling code doesn’t check for integer value of stake > number of seats.
EpochOutOfBounds(EpochId)
Requesting validators for an epoch that wasn’t computed yet.
MissingBlock(CryptoHash)
Missing block hash in the storage (means there is some structural issue).
IOErr(String)
Error due to IO (DB read/write, serialization, etc.).
NotAValidator(AccountId, EpochId)
Given account ID is not a validator in the given epoch ID.
ShardingError(String)
Error getting information for a shard
NotEnoughValidators