pub enum InvalidSpiceCoreStatementsError {
NoPrevUncertifiedChunks,
NoShardIdsForEpochId {
index: usize,
error: EpochError,
},
InvalidCoreStatement {
index: usize,
reason: &'static str,
},
SkippedExecutionResult {
chunk_id: SpiceChunkId,
},
NoValidatorAssignments {
shard_id: ShardId,
epoch_id: EpochId,
height_created: BlockHeight,
error: EpochError,
},
NoExecutionResultForEndorsedChunk {
chunk_id: SpiceChunkId,
},
UnknownBlock {
block_hash: CryptoHash,
},
IoError {
error: Error,
},
}Variants
NoPrevUncertifiedChunks
Information about uncertified chunks for previous block is missing.
NoShardIdsForEpochId
Could not find shard_ids for endorsement epoch.
InvalidCoreStatement
Spice core statement is invalid.
SkippedExecutionResult
Spice core statements skipped over execution result for chunk.
Fields

chunk_id: SpiceChunkIdNoValidatorAssignments
Could not find validator assignment for chunk.
NoExecutionResultForEndorsedChunk
Execution results for endorsed chunk are missing from block.
Fields

chunk_id: SpiceChunkIdUnknownBlock
Could not find block corresponding to endorsement.
Fields

block_hash: CryptoHashIoError
Encountered io error