Enum near_primitives::errors::InvalidTxError
source · [−]pub enum InvalidTxError {
Show 14 variants
InvalidAccessKeyError(InvalidAccessKeyError),
InvalidSignerId {
signer_id: String,
},
SignerDoesNotExist {
signer_id: AccountId,
},
InvalidNonce {
tx_nonce: Nonce,
ak_nonce: Nonce,
},
NonceTooLarge {
tx_nonce: Nonce,
upper_bound: Nonce,
},
InvalidReceiverId {
receiver_id: String,
},
InvalidSignature,
NotEnoughBalance {
signer_id: AccountId,
balance: Balance,
cost: Balance,
},
LackBalanceForState {
signer_id: AccountId,
amount: Balance,
},
CostOverflow,
InvalidChain,
Expired,
ActionsValidation(ActionsValidationError),
TransactionSizeExceeded {
size: u64,
limit: u64,
},
}Expand description
An error happened during TX execution
Variants
InvalidAccessKeyError(InvalidAccessKeyError)
Happens if a wrong AccessKey used or AccessKey has not enough permissions
InvalidSignerId
Fields
signer_id: StringTX signer_id is not a valid AccountId
SignerDoesNotExist
Fields
signer_id: AccountIdTX signer_id is not found in a storage
InvalidNonce
Transaction nonce must be account[access_key].nonce + 1.
NonceTooLarge
Transaction nonce is larger than the upper bound given by the block height
InvalidReceiverId
Fields
receiver_id: StringTX receiver_id is not a valid AccountId
InvalidSignature
TX signature is not valid
NotEnoughBalance
Account does not have enough balance to cover TX cost
LackBalanceForState
Fields
signer_id: AccountIdAn account which doesn’t have enough balance to cover storage.
amount: BalanceRequired balance to cover the state.
Signer account doesn’t have enough balance after transaction.
CostOverflow
An integer overflow occurred during transaction cost estimation.
InvalidChain
Transaction parent block hash doesn’t belong to the current chain
Expired
Transaction has expired
ActionsValidation(ActionsValidationError)
An error occurred while validating actions of a Transaction.
TransactionSizeExceeded
The size of serialized transaction exceeded the limit.