#[repr(u8)]pub enum PrepareError {
Show 19 variants
Serialization = 0,
Deserialization = 1,
InternalMemoryDeclared = 2,
GasInstrumentation = 3,
StackHeightInstrumentation = 4,
Instantiate = 5,
Memory = 6,
TooManyFunctions = 7,
TooManyLocals = 8,
TooManyTables = 9,
TooManyTableElements = 10,
FunctionBodyTooLarge = 11,
InstrumentedCodeTooLarge = 12,
TooManyBlocksPerFunction = 13,
TooManyBlocksPerContract = 14,
TooManyTypes = 15,
TooManyParamsPerFunction = 16,
TooManyParamsPerContract = 17,
OperandStackTooLarge = 18,
}Expand description
Error that can occur while preparing or executing Wasm smart-contract.
Variants
Serialization = 0
Error happened while serializing the module.
Deserialization = 1
Error happened while deserializing the module.
InternalMemoryDeclared = 2
Internal memory declaration has been found in the module.
GasInstrumentation = 3
Gas instrumentation failed.
This most likely indicates the module isn’t valid.
StackHeightInstrumentation = 4
Stack instrumentation failed.
This most likely indicates the module isn’t valid.
Instantiate = 5
Error happened during instantiation.
This might indicate that start function trapped, or module isn’t
instantiable and/or un-linkable.
Memory = 6
Error creating memory.
TooManyFunctions = 7
Contract contains too many functions.
TooManyLocals = 8
Contract contains too many locals.
TooManyTables = 9
Contract contains too many tables.
TooManyTableElements = 10
Contract contains too many table elements.
FunctionBodyTooLarge = 11
A function body in the contract exceeds the size limit.
InstrumentedCodeTooLarge = 12
The instrumented code exceeds the size limit.
TooManyBlocksPerFunction = 13
A function contains too many basic blocks.
TooManyBlocksPerContract = 14
A contract contains too many basic blocks.
TooManyTypes = 15
Contract declares too many entries in the wasm type section.
TooManyParamsPerFunction = 16
All contract functions combined have more than max_params_per_contract parameters.
TooManyParamsPerContract = 17
A function has more than max_params_per_function parameters.
OperandStackTooLarge = 18
A function’s max operand-stack size (in bytes) exceeds
max_operand_stack_bytes_per_function.