pub enum ReceiptValidationError {
InvalidPredecessorId {
account_id: String,
},
InvalidReceiverId {
account_id: String,
},
InvalidSignerId {
account_id: String,
},
InvalidDataReceiverId {
account_id: String,
},
ReturnedValueLengthExceeded {
length: u64,
limit: u64,
},
NumberInputDataDependenciesExceeded {
number_of_input_data_dependencies: u64,
limit: u64,
},
ActionsValidation(ActionsValidationError),
}Expand description
Describes the error for validating a receipt.
Variants
InvalidPredecessorId
Fields
account_id: StringThe predecessor_id of a Receipt is not valid.
InvalidReceiverId
Fields
account_id: StringThe receiver_id of a Receipt is not valid.
InvalidSignerId
Fields
account_id: StringThe signer_id of an ActionReceipt is not valid.
InvalidDataReceiverId
Fields
account_id: StringThe receiver_id of a DataReceiver within an ActionReceipt is not valid.
ReturnedValueLengthExceeded
The length of the returned data exceeded the limit in a DataReceipt.
NumberInputDataDependenciesExceeded
The number of input data dependencies exceeds the limit in an ActionReceipt.
ActionsValidation(ActionsValidationError)
An error occurred while validating actions of an ActionReceipt.