pub enum RuntimeError {
    UnexpectedIntegerOverflow,
    InvalidTxError(InvalidTxError),
    StorageError(StorageError),
    BalanceMismatchError(BalanceMismatchError),
    ReceiptValidationError(ReceiptValidationError),
    ValidatorError(EpochError),
}
Error returned from Runtime::apply

Variants

UnexpectedIntegerOverflow

An unexpected integer overflow occurred. The likely issue is an invalid state or the transition.

InvalidTxError(InvalidTxError)

An error happened during TX verification and account charging. It’s likely the chunk is invalid. and should be challenged.

StorageError(StorageError)

Unexpected error which is typically related to the node storage corruption. It’s possible the input state is invalid or malicious.

BalanceMismatchError(BalanceMismatchError)

An error happens if check_balance fails, which is likely an indication of an invalid state.

ReceiptValidationError(ReceiptValidationError)

The incoming receipt didn’t pass the validation, it’s likely a malicious behaviour.

ValidatorError(EpochError)

Error when accessing validator information. Happens inside epoch manager.