Enum near_primitives::errors::StorageError
source · [−]pub enum StorageError {
StorageInternalError,
TrieNodeMissing,
StorageInconsistentState(String),
}Expand description
Internal
Variants
StorageInternalError
Key-value db internal failure
TrieNodeMissing
Storage is PartialStorage and requested a missing trie node
StorageInconsistentState(String)
Either invalid state or key-value db is corrupted. For PartialStorage it cannot be corrupted. Error message is unreliable and for debugging purposes only. It’s also probably ok to panic in every place that produces this error. We can check if db is corrupted by verifying everything in the state trie.