pub enum ChunkType<'a> {
New(&'a ShardChunkHeader),
Old(&'a ShardChunkHeader),
}Expand description
Distinguishes between new and old chunks. Note: Some of the data of the cold chunk may be incompatible with the current protocol version. Example in case of resharding, if the child shard chunk is missing in the first block. the shard_id of the old chunk may be different from the shard_id of the new chunk.
Variants
New(&'a ShardChunkHeader)
Old(&'a ShardChunkHeader)
Implementations
Methods from Deref<Target = ShardChunkHeader>
pub fn inner_header_hash(&self) -> CryptoHash
Sourcepub fn height_created(&self) -> BlockHeight
pub fn height_created(&self) -> BlockHeight
Height at which the chunk was created.
TODO: this is always height(prev_block_hash) + 1. Consider using
prev_block_height instead as this is more explicit and
height_created also conflicts with height_included.
pub fn signature(&self) -> &Signature
pub fn height_included(&self) -> BlockHeight
pub fn is_new_chunk(&self, block_height: BlockHeight) -> bool
pub fn prev_validator_proposals(&self) -> ValidatorStakeIter<'_> ⓘ
pub fn prev_state_root(&self) -> StateRoot
pub fn prev_block_hash(&self) -> &CryptoHash
pub fn is_genesis(&self) -> bool
pub fn encoded_merkle_root(&self) -> &CryptoHash
pub fn shard_id(&self) -> ShardId
pub fn encoded_length(&self) -> u64
pub fn prev_gas_used(&self) -> Gas
pub fn gas_limit(&self) -> Gas
pub fn prev_balance_burnt(&self) -> Balance
pub fn prev_outgoing_receipts_root(&self) -> &CryptoHash
pub fn prev_outcome_root(&self) -> &CryptoHash
pub fn tx_root(&self) -> &CryptoHash
pub fn chunk_hash(&self) -> &ChunkHash
pub fn congestion_info(&self) -> CongestionInfo
pub fn bandwidth_requests(&self) -> Option<&BandwidthRequests>
Sourcepub fn validate_version(
&self,
version: ProtocolVersion,
) -> Result<(), BadHeaderForProtocolVersionError>
pub fn validate_version( &self, version: ProtocolVersion, ) -> Result<(), BadHeaderForProtocolVersionError>
Returns whether the header is valid for given ProtocolVersion.
pub fn is_spice_chunk(&self) -> bool
pub fn compute_hash(&self) -> ChunkHash
pub fn proposed_split(&self) -> Option<&TrieSplit>